SchemaSpy - Table gnss_data.public.stationinfo

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.stationinfo | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
NetworkCode | varchar | 3 |  |  |  |  |
stations.NetworkCode | stationinfo_NetworkCode_StationCode_fkey R
StationCode | varchar | 4 |  |  |  |  |
stations.StationCode | stationinfo_NetworkCode_StationCode_fkey R
ReceiverCode | varchar | 22 |  |  |  |  |
receivers.ReceiverCode | stationinfo_ReceiverCode_fkey R
ReceiverSerial | varchar | 22 | √ |  | null |  |  |
ReceiverFirmware | varchar | 10 | √ |  | null |  |  |
AntennaCode | varchar | 22 |  |  |  |  |
antennas.AntennaCode | stationinfo_AntennaCode_fkey R
AntennaSerial | varchar | 20 | √ |  | null |  |  |
AntennaHeight | numeric | 6,4 | √ |  | null |  |  |
AntennaNorth | numeric | 12,4 | √ |  | null |  |  |
AntennaEast | numeric | 12,4 | √ |  | null |  |  |
HeightCode | varchar | 2147483647 | √ |  | null |  |  |
RadomeCode | varchar | 7 |  |  |  |  |  |
DateStart | timestamp | 29,6 |  |  |  |  |  |
DateEnd | timestamp | 29,6 | √ |  | null |  |  |
ReceiverVers | varchar | 22 | √ |  | null |  |  |
Table contained 998 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: